sherlock.core


*base-index-location*clj


*page-size*clj


download-needed?clj

(download-needed? url)

ensure-fresh-indexclj

(ensure-fresh-index url)

get-pageclj

(get-page page results)

Get a specific page of results from a sequence of results.

Get a specific page of results from a sequence of results.
raw docstring

index-locationclj

(index-location url)

parse-resultclj

(parse-result data)

remote-index-urlclj

(remote-index-url url)

(search url query & [pages])

Search a maven repository. Takes a URL to the maven repo, the query string, and optionally the number of pages you'd like to fetch, where each page is page-size results long (25 by default). By default, search will fetch 2 pages. You can get specific pages by using the get-pages function. Returns a sequence of maps of artifacts. Each map has the following keys: :version, :artifact-id, :group-id, :classifier, :sha1, :name, :description, :updated, :size, and :packaging. Metadata on the sequence includes :_total-hits and :_max-score keys.

Sherlock looks for indexes in ~/.sherlock by default. This can be changed by setting base-index-location. If the index for the repository that you're searching is not found, Sherlock will download the index and place it in base-index-location. This can take a while, as some indexes are very large.

Search a maven repository. Takes a URL to the maven repo, the query string, and
optionally the number of pages you'd like to fetch, where each page is *page-size*
results long (25 by default). By default, search will fetch 2 pages. You can get specific
pages by using the get-pages function. Returns a sequence of maps of artifacts. Each map
has the following keys: :version, :artifact-id, :group-id, :classifier, :sha1, :name,
:description, :updated, :size, and :packaging. Metadata on the sequence includes
:_total-hits and :_max-score keys.

Sherlock looks for indexes in ~/.sherlock by default. This can be changed by setting
*base-index-location*. If the index for the repository that you're searching is not
found, Sherlock will download the index and place it in *base-index-location*. This
can take a while, as some indexes are very large.
raw docstring

search-repositoryclj

(search-repository url query page)

update-indexclj

(update-index url)

Redownload the index for a given repository.

Redownload the index for a given repository.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries